@@ -49,22 +49,23 @@
 
 package com.openexchange.caldav.reports;
 
-import java.io.IOException;
+import static com.openexchange.webdav.protocol.Protocol.DAV_NS;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 import org.jdom2.Document;
 import org.jdom2.Element;
-import org.jdom2.JDOMException;
-import org.jdom2.Namespace;
 import com.openexchange.caldav.CaldavProtocol;
 import com.openexchange.caldav.GroupwareCaldavFactory;
-import com.openexchange.webdav.action.WebdavPropfindAction;
+import com.openexchange.dav.DAVProtocol;
+import com.openexchange.dav.actions.PROPFINDAction;
 import com.openexchange.webdav.action.WebdavRequest;
 import com.openexchange.webdav.action.WebdavResponse;
 import com.openexchange.webdav.protocol.Protocol;
 import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
+import com.openexchange.webdav.protocol.WebdavResource;
+import com.openexchange.webdav.xml.resources.PropertiesMarshaller;
 import com.openexchange.webdav.xml.resources.ResourceMarshaller;
 
 /**
@@ -72,58 +73,48 @@ import com.openexchange.webdav.xml.resources.ResourceMarshaller;
  *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  */
-public class CaldavMultigetReport extends WebdavPropfindAction {
+public class CaldavMultigetReport extends PROPFINDAction {
 
     public static final String NAMESPACE = CaldavProtocol.CAL_NS.getURI();
-
     public static final String NAME = "calendar-multiget";
 
-    public CaldavMultigetReport(Protocol protocol) {
+    /**
+     * Initializes a new {@link CaldavMultigetReport}.
+     *
+     * @param protocol The protocol
+     */
+    public CaldavMultigetReport(DAVProtocol protocol) {
         super(protocol);
     }
 
     @Override
-    public void perform(WebdavRequest req, WebdavResponse res) throws WebdavProtocolException {
-        final Element response = new Element("multistatus", DAV_NS);
-
-        List<Namespace> namespaces = protocol.getAdditionalNamespaces();
-        for (Namespace namespace : namespaces) {
-            response.addNamespaceDeclaration(namespace);
+    public void perform(WebdavRequest request, WebdavResponse response) throws WebdavProtocolException {
+        /*
+         * get paths of requested resources
+         */
+        Document requestBody = requireRequestBody(request);
+        List<WebdavPath> paths = getPaths(request, requestBody);
+        /*
+         * marshal requested resources
+         */
+        ResourceMarshaller marshaller = getMarshaller(request, requireRequestBody(request));
+        PropertiesMarshaller helper = new PropertiesMarshaller(request.getURLPrefix(), request.getCharset());
+        Element multistatusElement = prepareMultistatusElement();
+        for (WebdavPath path : paths) {
+            try {
+                WebdavResource resource = request.getFactory().resolveResource(path);
+                multistatusElement.addContent(marshaller.marshal(resource));
+            } catch (WebdavProtocolException e) {
+                multistatusElement.addContent(new Element("response", Protocol.DAV_NS)
+                    .addContent(helper.marshalHREF(path, false))
+                    .addContent(helper.marshalStatus(e.getStatus()))
+                );
+            }
         }
-
-        final Document responseBody = new Document(response);
-
-        boolean forceAllProp = false;
-        Document requestBody = null;
-        try {
-            requestBody = req.getBodyAsDocument();
-        } catch (JDOMException e) {
-            forceAllProp = true;
-        } catch (IOException e) {
-            forceAllProp = true;
-        }
-
-        ResourceMarshaller marshaller = getMarshaller(req, forceAllProp, requestBody, null);
-
-        List<WebdavPath> paths = getPaths(req, requestBody);
-
-        List<Element> all = new ArrayList<Element>();
-
-        for (WebdavPath webdavPath : paths) {
-            List<Element> marshalled = marshaller.marshal(req.getFactory().resolveResource(webdavPath));
-            all.addAll(marshalled);
-        }
-
-        response.addContent(all);
-
-        try {
-            res.setStatus(Protocol.SC_MULTISTATUS);
-            res.setContentType("text/xml; charset=UTF-8");
-            outputter.output(responseBody, res.getOutputStream());
-        } catch (final IOException e) {
-            // IGNORE
-        }
-
+        /*
+         * send multistatus response
+         */
+        sendMultistatusResponse(response, multistatusElement);
     }
 
     private List<WebdavPath> getPaths(WebdavRequest req, Document requestBody) throws WebdavProtocolException {
