@@ -49,24 +49,16 @@
 
 package com.openexchange.caldav.resources;
 
-import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Date;
-import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import javax.servlet.http.HttpServletResponse;
-import org.jdom2.Document;
-import org.jdom2.Element;
-import org.jdom2.JDOMException;
-import com.openexchange.caldav.CalDAVPermission;
 import com.openexchange.caldav.CaldavProtocol;
 import com.openexchange.caldav.GroupwareCaldavFactory;
 import com.openexchange.caldav.Tools;
@@ -89,10 +81,8 @@ import com.openexchange.dav.DAVProtocol;
 import com.openexchange.dav.PreconditionException;
 import com.openexchange.dav.mixins.CalendarColor;
 import com.openexchange.dav.resources.CommonFolderCollection;
-import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
 import com.openexchange.folderstorage.AbstractFolder;
-import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.folderstorage.type.PrivateType;
 import com.openexchange.folderstorage.type.PublicType;
@@ -101,12 +91,10 @@ import com.openexchange.groupware.container.CalendarObject;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
 import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.user.UserService;
 import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProperty;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
 import com.openexchange.webdav.protocol.WebdavResource;
-import com.openexchange.xml.jdom.JDOMParser;
 
 /**
  * {@link CalDAVFolderCollection}
@@ -247,182 +235,6 @@ public abstract class CalDAVFolderCollection<T extends CalendarObject> extends C
 
     }
 
-    @Override
-    public void putBody(InputStream data, boolean guessSize) throws WebdavProtocolException {
-        try {
-            Document document = factory.getService(JDOMParser.class).parse(data);
-            if (null == document.getRootElement() || false == "share".equals(document.getRootElement().getName()) || false == CaldavProtocol.CALENDARSERVER_NS.equals(document.getRootElement().getNamespace())) {
-                throw WebdavProtocolException.generalError(getUrl(), HttpServletResponse.SC_BAD_REQUEST);
-            }
-            if (false == getFolder().getOwnPermission().isAdmin()) {
-                throw WebdavProtocolException.generalError(getUrl(), HttpServletResponse.SC_FORBIDDEN);
-            }
-            List<Permission> permissionsToSet = extractPermissionsToSet(document);
-            Set<Integer> permissionsEntitiesToRemove = extractPermissionsToRemove(document);
-            boolean hasChanged = false;
-            List<Permission> updatedPermissions = new ArrayList<Permission>();
-            Permission[] permissions = getFolder().getPermissions();
-            // remove / update
-            for (Permission permission : permissions) {
-                if (permission.isAdmin()) {
-                    updatedPermissions.add(permission);
-                    continue;
-                }
-                if (permissionsEntitiesToRemove.contains(Integer.valueOf(permission.getEntity()))) {
-                    // don't add
-                    hasChanged = true;
-                    continue;
-                }
-                Iterator<Permission> iterator = permissionsToSet.iterator();
-                while (iterator.hasNext()) {
-                    Permission permissionToSet = iterator.next();
-                    if (permission.getEntity() == permissionToSet.getEntity()) {
-                        // update
-                        permission = permissionToSet;
-                        iterator.remove();
-                        hasChanged = true;
-                        break;
-                    }
-                }
-                updatedPermissions.add(permission);
-            }
-            // add remaining
-            if (0 < permissionsToSet.size()) {
-                updatedPermissions.addAll(permissionsToSet);
-                hasChanged = true;
-            }
-            if (hasChanged) {
-                AbstractFolder updatableFolder = getFolderToUpdate();
-                updatableFolder.setPermissions(updatedPermissions.toArray(new Permission[updatedPermissions.size()]));
-                factory.getFolderService().updateFolder(updatableFolder, folder.getLastModifiedUTC(), factory.getSession(), null);
-            }
-        } catch (JDOMException e) {
-            throw WebdavProtocolException.generalError(e, getUrl(), HttpServletResponse.SC_BAD_REQUEST);
-        } catch (IOException e) {
-            throw WebdavProtocolException.generalError(e, getUrl(), HttpServletResponse.SC_BAD_REQUEST);
-        } catch (OXException e) {
-            if (e.getCategory().equals(Category.CATEGORY_PERMISSION_DENIED)) {
-                throw WebdavProtocolException.generalError(e, getUrl(), HttpServletResponse.SC_FORBIDDEN);
-            } else {
-                throw WebdavProtocolException.generalError(e, getUrl(), HttpServletResponse.SC_BAD_REQUEST);
-            }
-        }
-    }
-
-    /**
-     * Gets a list of permission entities that are requested to remove in the supplied "share" document.
-     *
-     * @param document The document body of the request
-     * @return A set of permission entities to remove, or an empty set if there are none
-     */
-    private Set<Integer> extractPermissionsToRemove(Document document) {
-        Set<Integer> permissionsEntitiesToRemove = new HashSet<Integer>();
-        for (Element element : document.getRootElement().getChildren("remove", CaldavProtocol.CALENDARSERVER_NS)) {
-            try {
-                Element hrefElement = element.getChild("href", CaldavProtocol.DAV_NS);
-                int entity = discoverUserID(hrefElement);
-                if (-1 == entity) {
-                    entity = discoverGroupID(hrefElement);
-                    if (-1 == entity) {
-                        continue;
-                    }
-                }
-                permissionsEntitiesToRemove.add(entity);
-            } catch (OXException e) {
-                LOG.warn("Error resolving share entitites", e);
-            }
-        }
-        return permissionsEntitiesToRemove;
-    }
-
-    /**
-     * Gets a list of permissions that are requested to set in the supplied "share" document.
-     *
-     * @param document The document body of the request
-     * @return The list of permissions to set, or an empty list if there are none
-     */
-    private List<Permission> extractPermissionsToSet(Document document) {
-        List<Permission> permissionsToSet = new ArrayList<Permission>();
-        for (Element element : document.getRootElement().getChildren("set", CaldavProtocol.CALENDARSERVER_NS)) {
-            try {
-                Element hrefElement = element.getChild("href", CaldavProtocol.DAV_NS);
-                boolean group = false;
-                int entity = discoverUserID(hrefElement);
-                if (-1 == entity) {
-                    entity = discoverGroupID(hrefElement);
-                    if (-1 == entity) {
-                        continue;
-                    }
-                    group = true;
-                }
-                if (null != element.getChild("read", CaldavProtocol.CALENDARSERVER_NS)) {
-                    permissionsToSet.add(CalDAVPermission.createReadOnlyForEntity(entity, group));
-                } else if (null != element.getChild("read-write", CaldavProtocol.CALENDARSERVER_NS)) {
-                    permissionsToSet.add(CalDAVPermission.createReadWriteForEntity(entity, group));
-                }
-            } catch (OXException e) {
-                LOG.warn("Error resolving share entitites", e);
-            }
-        }
-        return permissionsToSet;
-    }
-
-    private int discoverGroupID(Element hrefElement) throws OXException {
-        if (null != hrefElement && null != hrefElement.getText()) {
-            String text = hrefElement.getText();
-            if (text.startsWith("mailto:")) {
-                text = text.substring(7);
-            }
-            if (text.startsWith("/principals/groups/")) {
-                /*
-                 * get group by id
-                 */
-                String value = text.substring(19);
-                if ('/' == value.charAt(value.length() - 1)) {
-                    value = value.substring(0, value.length() - 1);
-                }
-                try {
-                    return Integer.valueOf(value);
-                } catch (NumberFormatException e) {
-                    LOG.debug("Error parsing group identifier '{}'", value, e);
-                }
-            }
-        }
-        return -1;
-    }
-
-    private int discoverUserID(Element hrefElement) throws OXException {
-        if (null != hrefElement && null != hrefElement.getText()) {
-            String text = hrefElement.getText();
-            if (text.startsWith("mailto:")) {
-                text = text.substring(7);
-            }
-            if (text.startsWith("/principals/")) {
-                if (text.startsWith("/principals/users/")) {
-                    /*
-                     * get user by id or login info
-                     */
-                    String value = text.substring(18);
-                    if ('/' == value.charAt(value.length() - 1)) {
-                        value = value.substring(0, value.length() - 1);
-                    }
-                    try {
-                        return Integer.valueOf(value);
-                    } catch (NumberFormatException e) {
-                        LOG.debug("Error parsing user identifier '{}'", value, e);
-                    }
-                    return factory.getService(UserService.class).getUserId(value, factory.getContext());
-                }
-                return -1; // other principal
-            }
-            /*
-             * search by mail address
-             */
-            return factory.getService(UserService.class).searchUser(text, factory.getContext()).getId();
-        }
-        return -1;
-    }
-
     protected static <T extends CalendarObject> boolean isInInterval(T object, Date intervalStart, Date intervalEnd) {
         return null != object && (null == object.getEndDate() || object.getEndDate().after(intervalStart)) && (null == object.getStartDate() || object.getStartDate().before(intervalEnd));
     }
